# edprompt
python shell edit 🤣🤣🤣

*`pip install edprompt`*

# how 2 use?

```python
>>> import edprompt
>>>
>>> "buy me a beer"
>>> -y
buy me a beer
save as : but_nobody.txt
>>>
>>> "tlqkf"
>>> -y
save as : tlqkf.txt
>>>
>>> "but_nobody.txt"
>>> +y
buy me a beer
'buy me a beer'
>>> -y
save as : dummy.txt
>>>
```

# deps
[funny](https://pypi.org/clro)
 